---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

## *Specifications*
- OS: `Arch Linux x86_64` <!-- neofetch -->
- Terminal: `alacritty 0.12.2 (9d9982df)` <!-- alacritty --version -->
- TUIFI Version: `v.3.0.0` <!-- tuifi --version -->

## *Describe the bug*
A clear and concise description of what the bug is.

## *Additional context*
Add any other context about the problem here.
